@@ -1,6 +1,6 @@
 #' @export
 
-E.piPS<-function(y,Pik){
+E.piPS <-function(y,Pik){
   y<-cbind(1,y)
   y<-as.data.frame(y)
   names(y)[1] <- "N"
@@ -17,7 +17,11 @@ E.piPS<-function(y,Pik){
     ystar <- Pik*P1/P2
     P3 <- ck/(Pik^2)
     #--------------------
-    Vty<-sum(P3*((y[,k]-ystar)^2))
+    if(sum(Pik) == n){
+      Vty <- 0
+    } else {
+      Vty <- sum(P3*((y[,k]-ystar)^2))
+    }
     CVe<-100*sqrt(Vty)/ty
     N<-sum(1/Pik)
     VMAS<-(N^2)*(1-(n/N))*var(y[,k])/(n)
@@ -25,4 +29,4 @@ E.piPS<-function(y,Pik){
     Total[,k]<-c(ty,sqrt(Vty),CVe,DEFF)
   }
   return(Total)
-}
\ No newline at end of file
+}
